@@ -53,6 +53,8 @@ sji.SPSS <- function(path, enc=NA, autoAttachVarLabels=FALSE) {
 #' @description This function retrieves the value labels of an imported
 #' SPSS data set and returns the result as list.
 #' 
+#' @references \url{http://rpubs.com/sjPlot/datainit}
+#' 
 #' @seealso \link{sji.SPSS} \cr
 #'          \link{sji.getVariableLabels} \cr
 #'          \link{sji.convertToLabel} \cr
@@ -85,9 +87,12 @@ getValLabels <- function(x){
 #' @title Attach value labels to a variable or vector
 #' @name sji.setValueLabels
 #' @description This function attaches character labels as \code{"value.labels"} attribute
-#'                to a variable or vector \code{"var"}. These value labels will be accessed
+#'                to a variable or vector \code{"x"}, resp. to all variables of a data frame
+#'                if \code{"x"} is a \code{\link{data.frame}}. These value labels will be accessed
 #'                by most of this package's functions, in order to automatically set values
 #'                or legend labels.
+#'                
+#' @references \url{http://rpubs.com/sjPlot/datainit}
 #' 
 #' @seealso \link{sji.SPSS} \cr
 #'          \link{sji.getVariableLabels} \cr
@@ -95,12 +100,14 @@ getValLabels <- function(x){
 #'          \link{sji.convertToValue} \cr
 #'          \link{sji.getValueLabels}
 #'
-#' @param var a variable (vector) where labels should be attached. Replaces former value labels.
-#' @param labels a character vector of labels that will be attached to \code{"var"} by setting
+#' @param x a variable (vector) or a data frame where labels should be attached. Replaces former value labels.
+#' @param labels a character vector of labels that will be attached to \code{"x"} by setting
 #'          the \code{"value.labels"} attribute. The length of this character vector must equal
-#'          the value range of \code{"var"}, i.e. if \code{"var"} has values from 1 to 3,
+#'          the value range of \code{"x"}, i.e. if \code{"x"} has values from 1 to 3,
 #'          \code{"labels"} should have a length of 3. 
-#' @return the variable \code{"var"} with attached value labels.
+#'          If \code{"x"} is a data frame, \code{labels} must be a \code{\link{list}} of
+#'          character vectors.
+#' @return \code{"x"} with attached value labels.
 #' 
 #' @examples
 #' dummy <- sample(1:4, 40, replace=TRUE)
@@ -110,14 +117,25 @@ getValLabels <- function(x){
 #' sjp.frq(dummy)
 #' 
 #' @export
-sji.setValueLabels <- function(var, labels) {
+sji.setValueLabels <- function(x, labels) {
+  if (is.vector(x)) {
+    return (sji.setValueLabels.vector(x, labels))
+  }
+  else if (is.data.frame(x) || is.matrix(x)) {
+    for (i in 1:ncol(x)) {
+      x[,i] <- sji.setValueLabels.vector(x[,i], labels[[i]])
+    }
+    return (x)
+  }
+}
+sji.setValueLabels.vector <- function(var, labels) {
   # check for null
   if (!is.null(labels)) {
     if (is.character(var) || is.null(var)) {
       cat("Can't attach labels to string or NULL vectors.\n")
     }
     else {
-      # checl if var ist a factor
+      # check if var is a factor
       if (is.factor(var)) {
         # retrieve levels
         minval <- 1
@@ -161,6 +179,8 @@ sji.setValueLabels <- function(var, labels) {
 #' @description This function retrieves the variable labels of an imported
 #' SPSS data set and returns the result as list.
 #' 
+#' @references \url{http://rpubs.com/sjPlot/datainit}
+#' 
 #' @seealso \link{sji.getValueLabels} \cr
 #'          \link{sji.setValueLabels} \cr
 #'          \link{sji.setVariableLabels} \cr
@@ -192,9 +212,11 @@ sji.getVariableLabels <- function(dat) {
 #' @description This function sets variable labels to a single variable or to
 #'                a set of variables in a data frame. To each variable, the
 #'                attribute \code{"variable.label"} with the related variable
-#'                name is attached. Most of this package's function can automatically
+#'                name is attached. Most of this package's functions can automatically
 #'                retrieve the variable name to use it as axis labels or plot title.
 #' 
+#' @references \url{http://rpubs.com/sjPlot/datainit}
+#' 
 #' @seealso \link{sji.getValueLabels} \cr
 #'          \link{sji.setValueLabels} \cr
 #'          \link{sji.getVariableLabels} \cr
