@@ -731,7 +731,7 @@ sju.mwu <- function(var, grp, alternative="two.sided") {
 #' @note This function is a convenient function for \code{\link{chisq.test}}, performing goodness-of-fit test.
 #' 
 #' @seealso \code{\link{sju.mwu}}, \code{\link{sju.aov1.levene}} and \code{\link{wilcox.test}}, \code{\link{ks.test}}, \code{\link{kruskal.test}}, 
-#'          \code{\link{t.test}}, \code{\link{chisq.test}}, \code{\link{fisher.test}}
+#'          \code{\link{t.test}}, \code{\link{chisq.test}}, \code{\link{fisher.test}}, \code{\link{ks.test}}
 #' 
 #' @examples
 #' data(efc)
@@ -786,6 +786,7 @@ sju.cronbach <- function(df) { # df must be matrix or data.frame with more than
 #'
 #' @seealso \code{\link{sju.cronbach}} \cr
 #'          \code{\link{sjt.itemanalysis}} \cr
+#'          \code{\link{sju.mic}} \cr
 #'          \code{\link{sjp.pca}} \cr
 #'          \code{\link{sjt.pca}} \cr
 #'          \code{\link{sjt.df}}
@@ -915,6 +916,73 @@ sju.reliability <- function(df, scaleItems=FALSE, digits=3) {
 }
 
 
+#' @title Computes a mean inter-item-correlation.
+#' @name sju.mic
+#' @description This function calculates a mean inter-item-correlation, i.e.
+#'                a correlation matrix of \code{data} will be computed (unless
+#'                \code{data} is already a \code{\link{cor}}-object) and the mean
+#'                of all added item's correlation values is returned.
+#'                Requires either a data frame or a computed \code{\link{cor}}-object.
+#'
+#' @seealso \code{\link{sju.cronbach}} \cr
+#'          \code{\link{sjt.itemanalysis}} \cr
+#'          \code{\link{sju.reliability}} \cr
+#'          \code{\link{sjp.pca}} \cr
+#'          \code{\link{sjt.pca}}
+#'          
+#' @param data A correlation object, built with the R-\code{\link{cor}}-function, or a data frame
+#'          which correlations should be calculated.
+#' @param corMethod Indicates the correlation computation method. May be one of
+#'          \code{"spearman"} (default), \code{"pearson"} or \code{"kendall"}.
+#' @return The value of the computed mean inter-item-correlation.
+#' 
+#' @examples
+#' # -------------------------------
+#' # Data from the EUROFAMCARE sample dataset
+#' # -------------------------------
+#' data(efc)
+#' # recveive first item of COPE-index scale
+#' start <- which(colnames(efc)=="c82cop1")
+#' # recveive last item of COPE-index scale
+#' end <- which(colnames(efc)=="c90cop9")
+#' # create data frame with COPE-index scale
+#' df <- as.data.frame(efc[,c(start:end)])
+#' 
+#' sju.mic(df)
+#' @export
+sju.mic <- function(data,
+                    corMethod="pearson") {
+  # -----------------------------------
+  # Mean-interitem-corelation
+  # -----------------------------------
+  if (class(data)=="matrix") {
+    corr <- data
+  }
+  else {
+    data <- na.omit(data)
+    corr <- cor(data, method=corMethod)
+  }
+  # -----------------------------------
+  # Sum up all correlation values
+  # -----------------------------------
+  mic <- c()
+  for (j in 1:(ncol(corr)-1)) {
+    # first correlation is always "1" (self-correlation)
+    for (i in (j+1):nrow(corr)) {
+      # check four valid bound
+      if (i<=nrow(corr) && j<=ncol(corr)) {
+        # add up all subsequent values
+        mic <- c(mic, corr[i,j])
+      }
+      else {
+        mic <- c(mic, "NA")
+      }
+    }
+  }
+  return (mean(mic))
+}
+
+
 #' @title Compute table's values
 #' @name sju.table.values
 #' @description This function calculates a table's cell, row and column percentages as
